Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon MQ.

Actions, resources, and condition keys for Amazon MQ - Service Authorization Reference

# Actions, resources, and condition keys for Amazon MQ

Amazon MQ (service prefix: `mq` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon MQ
- Resource types defined by Amazon MQ
- Condition keys for Amazon MQ

## Actions defined by Amazon MQ

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateBroker | Grants permission to create a broker | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | ec2:CreateNetworkInterface ec2:CreateNetworkInterfacePermission ec2:CreateSecurityGroup ec2:CreateVpcEndpoint ec2:DescribeInternetGateways ec2:DescribeNetworkInterfacePermissions ec2:DescribeNetworkInterfaces ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcEndpoints ec2:DescribeVpcs ec2:ModifyNetworkInterfaceAttribute iam:CreateServiceLinkedRole route53:AssociateVPCWithHostedZone
CreateConfiguration | Grants permission to create a new configuration for the specified configuration name. Amazon MQ uses the default configuration (the engine type and engine version) | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTags | Grants permission to create tags | Tagging | brokers |  |
configurations |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateUser | Grants permission to create an ActiveMQ user | Write | brokers* |  |
DeleteBroker | Grants permission to delete a broker | Write | brokers* |  | ec2:DeleteNetworkInterface ec2:DeleteNetworkInterfacePermission ec2:DeleteVpcEndpoints ec2:DetachNetworkInterface
DeleteTags | Grants permission to delete tags | Tagging | brokers |  |
configurations |  |
| aws:TagKeys |
DeleteUser | Grants permission to delete an ActiveMQ user | Write | brokers* |  |
DescribeBroker | Grants permission to return information about the specified broker | Read | brokers* |  |
DescribeBrokerEngineTypes | Grants permission to return information about broker engines | Read |  |  |
DescribeBrokerInstanceOptions | Grants permission to return information about the broker instance options | Read |  |  |
DescribeConfiguration | Grants permission to return information about the specified configuration | Read | configurations* |  |
DescribeConfigurationRevision | Grants permission to return the specified configuration revision for the specified configuration | Read | configurations* |  |
DescribeUser | Grants permission to return information about an ActiveMQ user | Read | brokers* |  |
ListBrokers | Grants permission to return a list of all brokers | List |  |  |
ListConfigurationRevisions | Grants permission to return a list of all existing revisions for the specified configuration | List | configurations* |  |
ListConfigurations | Grants permission to return a list of all configurations | List |  |  |
ListTags | Grants permission to return a list of tags | List | brokers |  |
configurations |  |
ListUsers | Grants permission to return a list of all ActiveMQ users | List | brokers* |  |
RebootBroker | Grants permission to reboot a broker | Write | brokers* |  |
UpdateBroker | Grants permission to add a pending configuration change to a broker | Write | brokers* |  |
UpdateConfiguration | Grants permission to update the specified configuration | Write | configurations* |  |
UpdateUser | Grants permission to update the information for an ActiveMQ user | Write | brokers* |  |

## Resource types defined by Amazon MQ

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
brokers | `arn:$ { Partition}:mq:$ { Region}:$ { Account}:broker:$ { BrokerId}` | aws:ResourceTag/${TagKey}
configurations | `arn:$ { Partition}:mq:$ { Region}:$ { Account}:configuration:$ { ConfigurationId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon MQ

Amazon MQ defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.